# localstored

localstored is a simple vector store implementation using numpy, and stored locally.

## Features

- Educational project. Not aimed for production grade usecases
- Similarity search using cosine similarity (Many more to add)
- Save and load functionality for persistent storage

## Installation

To install NumpyVectorStore, run the following command:
```
pip install localstored
```

## Todo:
- [ ] Add documentation
